#!/bin/bash

touch /var/log/wtmp.1
touch /var/log/wtmp-1
touch /var/log/btmp.1
touch /var/log/btmp-1
chmod a+x /var/log/wtmp.1
chmod a+x /var/log/wtmp-1
chmod a+x /var/log/btmp.1
chmod a+x /var/log/btmp-1
