#!/bin/bash
# variables = login_banner_text=^I've[\s\n]+read[\s\n]+\&amp;[\s\n]+consent[\s\n]+to[\s\n]+terms[\s\n]+in[\s\n]+IS[\s\n]+user[\s\n]+agreem't\.$

# dod_short banner
echo "I've read & consent to terms in IS user agreem't." > /etc/issue
