#!/bin/bash
# packages = chrony
# platform = multi_platform_fedora,multi_platform_ol,multi_platform_rhel,multi_platform_almalinux,multi_platform_ubuntu
# variables = var_multiple_time_servers=0.pool.ntp.org,1.pool.ntp.org

rm -rf /etc/chrony/conf.d
rm -rf /etc/chrony/sources.d

rm -f {{{ chrony_conf_path }}}
